==> rcquant_sdk-0.0.240407.16.tar.gz: rcquant_sdk-0.0.240407.16/rcquant_sdk/packer/chart/line_graph_param_data_packer.py <==
from ...interface import IPacker


class LineGraphParamDataPacker(IPacker):
    def __init__(self, obj) -> None:
        super().__init__(obj)

    def obj_to_tuple(self):
        return [str(self._obj.ID), str(self._obj.Name), int(self._obj.Style), str(self._obj.Color),
                int(self._obj.Width), int(self._obj.PlotIndex), int(self._obj.ValueAxisID), float(self._obj.PriceTick),
                float(self._obj.TickValidMul), bool(self._obj.ShowLegend), str(self._obj.LegendFormat), str(self._obj.LegendColor), str(self._obj.BindInsID),
                str(self._obj.BindRange), bool(self._obj.JoinValueAxis), float(self._obj.ValidMaxValue), float(self._obj.ValidMinValue), dict(self._obj.UserData),
                bool(self._obj.Visible), bool(self._obj.IsShowSymbol), int(self._obj.ShowSymbolLimit), bool(self._obj.RenderAntialiased)]

    def tuple_to_obj(self, t):
        if len(t) >= 22:
            self._obj.ID = t[0]
            self._obj.Name = t[1]
            self._obj.Style = t[2]
            self._obj.Color = t[3]
            self._obj.Width = t[4]
            self._obj.PlotIndex = t[5]
            self._obj.ValueAxisID = t[6]
            self._obj.PriceTick = t[7]
            self._obj.TickValidMul = t[8]
            self._obj.ShowLegend = t[9]
            self._obj.LegendFormat = t[10]
            self._obj.LegendColor = t[11]
            self._obj.BindInsID = t[12]
            self._obj.BindRange = t[13]
            self._obj.JoinValueAxis = t[14]
            self._obj.ValidMaxValue = t[15]
            self._obj.ValidMinValue = t[16]
            self._obj.UserData = t[17]
            self._obj.Visible = t[18]
            self._obj.IsShowSymbol = t[19]
            self._obj.ShowSymbolLimit = t[20]
            self._obj.RenderAntialiased = t[21]

            return True
        return False

==> rcquant_sdk-0.0.250925.15.tar.gz: rcquant_sdk-0.0.250925.15/rcquant_sdk/packer/chart/line_graph_param_data_packer.py <==
from ...interface import IPacker


class LineGraphParamDataPacker(IPacker):
    def __init__(self, obj) -> None:
        super().__init__(obj)

    def obj_to_tuple(self):
        return (str(self._obj.ID), str(self._obj.Name), int(self._obj.Style), str(self._obj.Color),
                int(self._obj.Width), int(self._obj.PlotIndex), int(self._obj.ValueAxisID), float(self._obj.PriceTick),
                float(self._obj.TickValidMul), bool(self._obj.ShowLegend), str(self._obj.LegendFormat), str(self._obj.LegendColor), str(self._obj.BindInsID),
                str(self._obj.BindRange), bool(self._obj.JoinValueAxis), float(self._obj.ValidMaxValue), float(self._obj.ValidMinValue), dict(self._obj.UserData),
                bool(self._obj.Visible), bool(self._obj.IsShowSymbol), int(self._obj.ShowSymbolLimit), bool(self._obj.RenderAntialiased))

    def tuple_to_obj(self, t):
        if len(t) >= 22:
            self._obj.ID = t[0]
            self._obj.Name = t[1]
            self._obj.Style = t[2]
            self._obj.Color = t[3]
            self._obj.Width = t[4]
            self._obj.PlotIndex = t[5]
            self._obj.ValueAxisID = t[6]
            self._obj.PriceTick = t[7]
            self._obj.TickValidMul = t[8]
            self._obj.ShowLegend = t[9]
            self._obj.LegendFormat = t[10]
            self._obj.LegendColor = t[11]
            self._obj.BindInsID = t[12]
            self._obj.BindRange = t[13]
            self._obj.JoinValueAxis = t[14]
            self._obj.ValidMaxValue = t[15]
            self._obj.ValidMinValue = t[16]
            self._obj.UserData = t[17]
            self._obj.Visible = t[18]
            self._obj.IsShowSymbol = t[19]
            self._obj.ShowSymbolLimit = t[20]
            self._obj.RenderAntialiased = t[21]

            return True
        return False
